.. _installation:

Installation
============

The recommended way to install is with ``pip``:

.. code-block:: console

   pip install alise

This way you will ensure that the stable version is fetched from pip, rather
than development or unstable version.

Installing the Development Version
----------------------------------

The development version can be installed from the ``master`` branch
of the `GitHub repository <https://github.com/marcvs/alise>`_ and
can be installed as follows (note the ``-e`` switch to install it in editable
or "develop mode"):

.. code-block:: console

   git clone https://github.com/marcvs/alise
   pip install -e ./alise
